@@ -1,3 +1,4 @@
+use solana_program::pubkey::Pubkey;
 use quick_protobuf::deserialize_from_slice;
 use solana_program::account_info::AccountInfo;
 use solana_program::program_error::ProgramError;
@@ -7,8 +8,8 @@ pub use switchboard_protos::protos::aggregator_state::AggregatorState;
 pub use switchboard_protos::protos::aggregator_state::mod_AggregatorState;
 pub use switchboard_protos::protos::aggregator_state::RoundResult;
 pub use switchboard_protos::protos::switchboard_account_types::SwitchboardAccountType;
-use zerocopy::AsBytes;
 use switchboard_protos::protos::vrf::VrfAccountData;
+use bytemuck::{bytes_of_mut};
 
 /// Returns whether the current open round is considered valid for usage.
 pub fn is_current_round_valid(aggregator: &AggregatorState) -> Result<bool, ProgramError> {
@@ -74,7 +75,7 @@ impl<'a> BundleAccount<'a> {
         let mut res = FastRoundResultAccountData {
             ..Default::default()
         };
-        let recv = res.as_bytes_mut();
+        let recv = bytes_of_mut(&mut res);
         recv.copy_from_slice(&buf[offset..term]);
         if res.result.round_open_slot == 0 {
             return Err(ProgramError::InvalidArgument);
